@@ -14,10 +14,11 @@
 # limitations under the License.
 #
 
-from taskr.taskr import Task
-from taskr.terminal import Console
+from .taskr import Task
+from .terminal import Console
+from .terminal import Color
 
 task = Task
 console = Console
 
-__all__ = [Task.__name__, Console.__name__, 'task', 'console']
+__all__ = [Task.__name__, Console.__name__, Color.__name__, 'task', 'console']
